@@ -4,6 +4,7 @@ TBIntLogger
 This service is used to log messages and data to Datadog.
 """
 
+import logging
 import os
 import time
 from typing import List, Optional
@@ -24,7 +25,7 @@ class LoggerData:
     Data class for TBIntLogger
     """
 
-    # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-arguments, too-many-positional-arguments
     def __init__(
         self,
         system=None,
@@ -128,33 +129,45 @@ class Logger:
         if self.dd_api_endpoint != "" and self.dd_api_key != "":
             try:
                 response = requests.post(
-                    url=self.dd_api_endpoint, json=log_message, headers=headers, timeout=5
+                    url=self.dd_api_endpoint,
+                    json=log_message,
+                    headers=headers,
+                    timeout=5,
                 )
                 if not str(response.status_code).startswith("2"):
                     log_res = response.json()
-                    print(
-                        f"Error logging: {response.status_code} {response.reason} {log_res}"
+                    logging.warning(
+                        "Error logging: %s %s %s",
+                        response.status_code,
+                        response.reason,
+                        log_res,
                     )
+            # pylint: disable=broad-except
             except Exception as e:
-                print(f"Error sending log to DataDog: {e}")
+                logging.warning("Error sending log to DataDog: %s", e)
 
     async def __request_async(self, headers, log_message):
         if self.dd_api_endpoint != "" and self.dd_api_key != "":
             try:
-                session =  aiohttp.ClientSession()
+                session = aiohttp.ClientSession()
                 response = await session.post(
                     url=self.dd_api_endpoint,
                     json=log_message,
                     headers=headers,
                     timeout=aiohttp.ClientTimeout(total=5),
                 )
+                await session.close()
                 if not str(response.status).startswith("2"):
                     log_res = await response.json()
-                    print(
-                        f"Error logging: {response.status} {response.reason} {log_res}"
+                    logging.warning(
+                        "Error logging: %s %s %s",
+                        response.status,
+                        response.reason,
+                        log_res,
                     )
+            # pylint: disable=broad-except
             except Exception as e:
-                print(f"Error sending log to DataDog: {e}")
+                logging.warning("Error sending log to DataDog: %s", e)
 
     def get_headers(self):
         """
@@ -169,7 +182,7 @@ class Logger:
             "DD-API-KEY": self.dd_api_key,
         }
 
-    def get_log_message(self, level, d: LoggerData):
+    def get_log_message(self, level, d: LoggerData) -> dict:
         """
         Get log message
 
@@ -222,14 +235,28 @@ class Logger:
         if self.should_log(level):
             headers = self.get_headers()
             log_message = self.get_log_message(level, data)
-            print(log_message)
+            if level == "info":
+                logging.info(log_message)
+            elif level == "debug":
+                logging.debug(log_message)
+            elif level == "warn":
+                logging.warning(log_message)
+            elif level == "error":
+                logging.error(log_message)
             await self.__request_async(headers, log_message)
 
     def __log_sync(self, level, data):
         if self.should_log(level):
             headers = self.get_headers()
             log_message = self.get_log_message(level, data)
-            print(log_message)
+            if level == "info":
+                logging.info(log_message)
+            elif level == "debug":
+                logging.debug(log_message)
+            elif level == "warn":
+                logging.warning(log_message)
+            elif level == "error":
+                logging.error(log_message)
             self.__request_sync(headers, log_message)
 
     def should_log(self, level):
